@@ -75,6 +75,7 @@ class Graph(object):
     def num_nodes(self):
         """
         Number of nodes
+
         :return: Number of nodes
         """
         return union_len(self.x)
@@ -83,6 +84,7 @@ class Graph(object):
     def num_edges(self):
         """
         Number of edges
+
         :return: Number of edges
         """
 
@@ -100,6 +102,7 @@ class Graph(object):
     def num_features(self):
         """
         Number of node features
+
         :return: Number of node features
         """
         return self.x.shape[-1]
@@ -131,6 +134,7 @@ class Graph(object):
     def convert_data_to_tensor(self):
         """
         Convert all graph data into Tensors. All corresponding properties will be replaces by their Tensor versions.
+
         :return: The Graph object itself.
         """
         return self._convert_data_to_tensor(["x", "edge_index", "edge_weight", "y"])
@@ -143,6 +147,7 @@ class Graph(object):
         This is not convenient for users.
         Thus, we allow users to provide edge_index in undirected form and convert it later.
         That is, we can only provide (u, v) and convert it to (u, v) and (v, u) with `convert_edge_to_directed` method.
+
         :return:
         """
         self.edge_index, [self.edge_weight] = convert_edge_to_directed(self.edge_index, [self.edge_weight])
@@ -312,11 +317,15 @@ class BatchGraph(Graph):
     def build_node_graph_index(cls, graphs):
         node_graph_index_list = []
 
-        for i, graph in enumerate(graphs):
-            node_graph_index_list.append(tf.fill([graph.num_nodes], i))
-
-        node_graph_index = tf.concat(node_graph_index_list, axis=0)
-        node_graph_index = tf.cast(node_graph_index, tf.int32)
+        if tf.is_tensor(graphs[0].edge_index):
+            for i, graph in enumerate(graphs):
+                node_graph_index_list.append(tf.fill([graph.num_nodes], i))
+            node_graph_index = tf.concat(node_graph_index_list, axis=0)
+            node_graph_index = tf.cast(node_graph_index, tf.int32)
+        else:
+            for i, graph in enumerate(graphs):
+                node_graph_index_list.append(np.full([graph.num_nodes], i, dtype=np.int32))
+            node_graph_index = np.concatenate(node_graph_index_list, axis=0)
 
         return node_graph_index
 
@@ -324,21 +333,29 @@ class BatchGraph(Graph):
     @classmethod
     def build_edge_graph_index(cls, graphs):
         edge_graph_index_list = []
-
-        for i, graph in enumerate(graphs):
-            edge_graph_index_list.append(tf.fill([graph.num_edges], i))
-
-        edge_graph_index = tf.concat(edge_graph_index_list, axis=0)
-        edge_graph_index = tf.cast(edge_graph_index, tf.int32)
+        if tf.is_tensor(graphs[0].edge_index):
+            for i, graph in enumerate(graphs):
+                edge_graph_index_list.append(tf.fill([graph.num_edges], i))
+            edge_graph_index = tf.concat(edge_graph_index_list, axis=0)
+            edge_graph_index = tf.cast(edge_graph_index, tf.int32)
+        else:
+            for i, graph in enumerate(graphs):
+                edge_graph_index_list.append(np.full([graph.num_edges], i, dtype=np.int32))
+            edge_graph_index = np.concatenate(edge_graph_index_list, axis=0)
 
         return edge_graph_index
 
 
     @classmethod
     def build_x(cls, graphs):
-        return tf.concat([
-            graph.x for graph in graphs
-        ], axis=0)
+        if tf.is_tensor(graphs[0].x):
+            return tf.concat([
+                graph.x for graph in graphs
+            ], axis=0)
+        else:
+            return np.concatenate([
+                graph.x for graph in graphs
+            ], axis=0)
 
     @classmethod
     def build_edge_index(cls, graphs):
@@ -348,30 +365,41 @@ class BatchGraph(Graph):
             edge_index_list.append(graph.edge_index + num_history_nodes)
             num_history_nodes += graph.num_nodes
 
-        return tf.concat(edge_index_list, axis=1)
+        if tf.is_tensor(graphs[0].edge_index):
+            return tf.concat(edge_index_list, axis=1)
+        else:
+            return np.concatenate(edge_index_list, axis=1)
 
     @classmethod
     def build_edge_weight(cls, graphs):
         if graphs[0].edge_weight is None:
             return None
-        else:
+        elif tf.is_tensor(graphs[0].edge_weight):
             return tf.concat([
                 graph.edge_weight for graph in graphs
             ], axis=0)
-
+        else:
+            return np.concatenate([
+                graph.edge_weight for graph in graphs
+            ], axis=0)
 
     @classmethod
     def build_y(cls, graphs):
         if graphs[0].y is None:
             return None
-        else:
+        elif tf.is_tensor(graphs[0].y):
             return tf.concat([
                 graph.y for graph in graphs
             ], axis=0)
+        else:
+            return np.concatenate([
+                graph.y for graph in graphs
+            ], axis=0)
 
     def convert_data_to_tensor(self):
         """
         Convert all graph data into Tensors. All corresponding properties will be replaces by their Tensor versions.
+
         :return: The Graph object itself.
         """
         return self._convert_data_to_tensor(["x", "edge_index", "edge_weight", "y",
@@ -385,6 +413,7 @@ class BatchGraph(Graph):
         This is not convenient for users.
         Thus, we allow users to provide edge_index in undirected form and convert it later.
         That is, we can only provide (u, v) and convert it to (u, v) and (v, u) with `convert_edge_to_directed` method.
+
         :return:
         """
         self.edge_index, [self.edge_weight, self.edge_graph_index] = \
