@@ -1,11 +1,17 @@
+# coding=utf-8
 from tf_geometric.layers.conv.gcn import GCN
 from tf_geometric.layers.conv.gat import GAT
-from tf_geometric.layers.kernel.map_reduce import MapReduceGNN
-from tf_geometric.layers.pool.mean_pool import MeanPool
 from tf_geometric.layers.conv.gin import GIN
 from tf_geometric.layers.conv.graph_sage import MeanGraphSage, MeanPoolGraphSage, MaxPoolGraphSage, GCNGraphSage, LSTMGraphSage
 from tf_geometric.layers.conv.sgc import SGC
 from tf_geometric.layers.conv.tagcn import TAGCN
 from tf_geometric.layers.conv.chebynet import ChebyNet
 from tf_geometric.layers.conv.appnp import APPNP
+
 from tf_geometric.layers.sampling.drop_edge import DropEdge
+
+from tf_geometric.layers.kernel.map_reduce import MapReduceGNN
+
+from tf_geometric.layers.pool.common_pool import MeanPool, MinPool, MaxPool, SumPool
+from tf_geometric.layers.pool.diff_pool import DiffPool
+from tf_geometric.layers.pool.set2set import Set2Set
